@@ -1,8 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LXDE-Qt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org
  *
  * Copyright: 2011-2012 Razor team
  * Authors:
@@ -81,7 +81,7 @@ void PolicykitAgent::initiateAuthentication(const QString &actionId,
     }
     m_gui = new PolicykitAgentGUI(actionId, message, iconName, details, identities);
 
-    foreach (PolkitQt1::Identity i, identities)
+    for(const PolkitQt1::Identity& i : identities)
     {
         PolkitQt1::Agent::Session *session;
         session = new PolkitQt1::Agent::Session(i, cookie, result);
